package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.ScoreRoom;

/**
 * 【请填写功能名称】Service接口
 * 
 * @author ruoyi
 * @date 2025-10-30
 */
public interface IScoreRoomService 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param roomId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public ScoreRoom selectScoreRoomByRoomId(Long roomId);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param scoreRoom 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<ScoreRoom> selectScoreRoomList(ScoreRoom scoreRoom);

    /**
     * 新增【请填写功能名称】
     * 
     * @param scoreRoom 【请填写功能名称】
     * @return 结果
     */
    public int insertScoreRoom(ScoreRoom scoreRoom);

    /**
     * 修改【请填写功能名称】
     * 
     * @param scoreRoom 【请填写功能名称】
     * @return 结果
     */
    public int updateScoreRoom(ScoreRoom scoreRoom);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param roomIds 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteScoreRoomByRoomIds(Long[] roomIds);

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param roomId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteScoreRoomByRoomId(Long roomId);
}
